==> jugg-agile-middleware-db-1.0.0-20251126.014959-1-sources.jar: com/jugg/agile/middleware/db/datasource/JaDataSourceConfiguration.java <==
package com.jugg.agile.middleware.db.datasource;

import com.jugg.agile.framework.core.util.JaThrowableUtil;
import com.jugg.agile.framework.core.util.datastructure.JaCollectionUtil;
import com.jugg.agile.middleware.db.datasource.aspect.JaConnectionAspect;
import com.jugg.agile.middleware.db.datasource.aspect.JaDataSourceAspect;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

import javax.sql.DataSource;
import java.util.Map;

@Configuration
@ConditionalOnProperty(name = "ja.datasource.enabled", havingValue = "true")
public class JaDataSourceConfiguration implements InitializingBean {
    @Bean
    @ConditionalOnMissingBean({DataSource.class})
    public DataSource dataSource() {
        JaDataSourceFactory.create();
        Map<String, DataSource> dataSourceMap = JaDataSourceFactory.get();
        if (JaCollectionUtil.isEmpty(dataSourceMap)) {
            JaThrowableUtil.throwRunLog("dataSourceMap is empty");
        }
        DataSource dataSource = dataSourceMap.get("default");
        if (null == dataSource) {
            dataSource = dataSourceMap.entrySet().iterator().next().getValue();
        }
        return dataSource;
    }

    @Bean
    public JaDataSourceAspect dataSourceAspect() {
        return new JaDataSourceAspect();
    }

    @Bean
    public JaConnectionAspect connectionAspect() {
        return new JaConnectionAspect();
    }

    @Override
    public void afterPropertiesSet() {
        if (null == JaDataSourceFactory.get()) {
            JaDataSourceFactory.create();
        }
    }
}

==> jugg-agile-middleware-db-3.5.3.0-20251202.132200-8-sources.jar: com/jugg/agile/middleware/db/datasource/JaDataSourceConfiguration.java <==
package com.jugg.agile.middleware.db.datasource;

import com.jugg.agile.framework.core.util.JaThrowableUtil;
import com.jugg.agile.framework.core.util.datastructure.JaCollectionUtil;
import com.jugg.agile.middleware.db.datasource.aspect.JaConnectionAspect;
import com.jugg.agile.middleware.db.datasource.aspect.JaDataSourceAspect;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.boot.autoconfigure.AutoConfigureBefore;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.jdbc.DataSourceAutoConfiguration;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import javax.sql.DataSource;
import java.util.Map;

@Configuration
@ConditionalOnProperty(name = "ja.datasource.enabled", havingValue = "true")
public class JaDataSourceConfiguration implements InitializingBean {
    @Bean
    @Primary
    @ConditionalOnMissingBean({DataSource.class})
    public DataSource dataSource() {
        JaDataSourceFactory.create();
        Map<String, DataSource> dataSourceMap = JaDataSourceFactory.get();
        if (JaCollectionUtil.isEmpty(dataSourceMap)) {
            JaThrowableUtil.throwRunLog("dataSourceMap is empty");
        }
        DataSource dataSource = dataSourceMap.get("default");
        if (null == dataSource) {
            dataSource = dataSourceMap.entrySet().iterator().next().getValue();
        }
        return dataSource;
    }

    @Bean
    public JaDataSourceAspect dataSourceAspect() {
        return new JaDataSourceAspect();
    }

    @Bean
    public JaConnectionAspect connectionAspect() {
        return new JaConnectionAspect();
    }

    @Override
    public void afterPropertiesSet() {
        if (null == JaDataSourceFactory.get()) {
            JaDataSourceFactory.create();
        }
    }
}
